@@ -5,6 +5,7 @@ from weaverbird.backends.sql_translator.types import (
     SQLPipelineTranslator,
     SQLQuery,
     SQLQueryDescriber,
+    SQLQueryExecutor,
     SqlQueryMetadataManager,
     SQLQueryRetriever,
 )
@@ -15,26 +16,36 @@ def translate_table(
     step: TableStep,
     query: SQLQuery,
     index: int,
-    sql_query_retriever: SQLQueryRetriever,
-    sql_query_describer: SQLQueryDescriber,
+    sql_query_retriever: SQLQueryRetriever = None,
+    sql_query_describer: SQLQueryDescriber = None,
+    sql_query_executor: SQLQueryExecutor = None,
     sql_translate_pipeline: SQLPipelineTranslator = None,
+    subcall_from_other_pipeline_count: int = None,
 ) -> SQLQuery:
     """As it is always the first step add the with keyword"""
     select_from_table = sql_query_retriever(
         step.domain
     )  # TODO in laputa, implement the table retrieval instead of query
     query_name = f'SELECT_STEP_{index}'
+    query_name += (
+        f'_{subcall_from_other_pipeline_count}'
+        if isinstance(subcall_from_other_pipeline_count, int)
+        and subcall_from_other_pipeline_count >= 0
+        else ''
+    )
+
     query_description = sql_query_describer(step.domain)
-    tables_metadata = {step.domain: query_description}
-    query_metadata = query_description
+    query_metadata_manager = SqlQueryMetadataManager(
+        tables_metadata={step.domain: query_description}
+    )
+
     sql_query = SQLQuery(
         query_name=query_name,
         transformed_query=f'WITH {query_name} AS ({select_from_table})',
-        selection_query=build_selection_query(query_metadata, query_name),
-        metadata_manager=SqlQueryMetadataManager(
-            tables_metadata=tables_metadata,
-            query_metadata=query_metadata,
+        selection_query=build_selection_query(
+            query_metadata_manager.retrieve_query_metadata_columns(), query_name
         ),
+        metadata_manager=query_metadata_manager,
     )
     # TODO adapt Laputa to directly return the SQLQuery
     return sql_query
